@@ -14,7 +14,7 @@ Please enter OPENAI API KEY:""")
     apiKey = apiKey.strip()
     assert "sk-" in apiKey, "API Key needs to start with sk-..."
     os.environ["OPENAI_API_KEY"] = apiKey
-  model = os.get("OPENAI_MODEL",'text-davinci-003')
+  model = os.environ.get("OPENAI_MODEL",'text-davinci-003')
   temperature = 0.
   maxTokens = 150
 
